@@ -63,5 +63,5 @@ class FCT(BlockFile):
     STD = {}
 
     def __init__(self, **OGS_Config):
-        super(FCT, self).__init__(**OGS_Config)
+        super().__init__(**OGS_Config)
         self.file_ext = ".fct"
