@@ -55,5 +55,5 @@ class RFD(BlockFile):
     STD = {}
 
     def __init__(self, **OGS_Config):
-        super(RFD, self).__init__(**OGS_Config)
+        super().__init__(**OGS_Config)
         self.file_ext = ".rfd"
